import json
import inspect
import os

globals_file = "globals.json"

def get_caller_filename():
    stack = inspect.stack()
    caller_frame = stack[1]
    return os.path.abspath(caller_frame.filename).replace("\\", "/")

def read_globals():
    if not os.path.exists(globals_file):
        return {}
    with open(globals_file, "r") as f:
        return json.load(f)

def write_globals(data):
    with open(globals_file, "w") as f:
        json.dump(data, f)

def set(name, value=None):
    caller_filename = get_caller_filename()
    data = read_globals()
    globals = data.get(caller_filename, {})
    globals[name] = value
    data[caller_filename] = globals
    write_globals(data)

def get(name):
    caller_filename = get_caller_filename()
    data = read_globals()
    globals = data.get(caller_filename, {})
    return globals.get(name)

def remove(name):
    caller_filename = get_caller_filename()
    data = read_globals()
    globals = data.get(caller_filename, {})
    globals.pop(name, None)
    data[caller_filename] = globals
    write_globals(data)
    return globals

def peek():
    caller_filename = get_caller_filename()
    data = read_globals()
    return data.get(caller_filename, {})



from setuptools import setup, find_packages

setup(
    name='glovar', 
    version='0.1.1',
    packages=find_packages(), 
    description='A package for managing JSON-based global variables by file context.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/PaceGG/Python-Global-vars-lib',  
    author='PaceGG',
    author_email='yura3012004@gmail.com',
    install_requires=[],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6', 
)
